Learn R Programming

IxPopDyMod (version 0.3.0)

annual_growth_rate: Calculate annual growth rate

Description

Calculate annual growth rate

Usage

annual_growth_rate(out)

Value

Numeric vector of length one representing the annual factor by which the total tick population changes. To use this function, it is best to run the model for at least three years.

Arguments

out

Model output data frame

Examples

Run this code
if (FALSE) {
out <- run(ogden2005)
annual_growth_rate(out)
}

Run the code above in your browser using DataLab