powered by
Calculate annual growth rate
annual_growth_rate(out)
Numeric vector of length one representing the annual factor by which the total tick population changes. To use this function, it is best to run the model for at least three years.
Model output data frame
if (FALSE) { out <- run(ogden2005) annual_growth_rate(out) }
Run the code above in your browser using DataLab